#
# spec file for package libtracefs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libtracefs
%define lname   libtracefs1
Version:        1.8.1
Release:        2.1
Summary:        Linux kernel trace file system library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://git.kernel.org/pub/scm/libs/libtrace/libtracefs.git/
Source:         https://git.kernel.org/pub/scm/libs/libtrace/libtracefs.git/snapshot/%name-%version.tar.gz
BuildRequires:  asciidoc
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  meson
BuildRequires:  pkg-config
BuildRequires:  source-highlight
BuildRequires:  xmlto
BuildRequires:  xz
BuildRequires:  pkgconfig(libtraceevent) >= 1.3

%description
This library provides C APIs to access the kernel trace file system.

%package -n %lname
Summary:        Linux kernel trace file system library
Group:          System/Libraries

%description -n %lname
This library provides C APIs to access the kernel trace file system.

%package tools
Summary:        Tools for libtracefs
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description tools
This library provides C APIs to access the kernel trace file system.

This subpackage contains tools.

%package devel
Summary:        Development files for libtracefs
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
This library provides C APIs to access the kernel trace file system.

This subpackage contains the header files.

%prep
%autosetup -p1

%build
%meson \
    --default-library=shared \
    -Dhtmldir="%_docdir/%name"
%meson_build
%meson_build docs

%install
%meson_install

%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libtracefs.so.1*
%license LICENSES/LGPL-2.1

%files tools
%_bindir/sqlhist
%_mandir/man1/*

%files devel
%_includedir/*
%_libdir/libtracefs.so
%_libdir/pkgconfig/*.pc
%_mandir/man3/*
%_docdir/%name/

%changelog
* Sat Jul 27 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.1
  * Plug some memory leaks
- Delete 0001-libtracefs-meson-build-tracefs-mmap-by-default.patch
  (merged)
* Mon Jun 17 2024 Daniel Wagner <daniel.wagner@suse.com>
- Update to v1.8.0
  * remove: add-explicit-meson-thread-dependency.patch
  * tracefs_follow_event_clear() and tracefs_follow_missed_events_clear()
    API to clean up followers if the tracefs instance is going to be used
    for other iterations
  * tracefs_instance_file_write_number()
    A simple helper function to make it easier to write numbers into the
    tracefs files. It does the conversion from number to string, as the
    files expect strings and not numbers.
  * Add API to work with kbuffer, which gives more control to the application
    and speeds it up:
    tracefs_cpu_read_buf()
    tracefs_cpu_buffered_read_buf()
    tracefs_cpu_flush_buf()
  * tracefs_instance_get_buffer_percent() and tracefs_instance_set_buffer_percent()
    Modify the buffer_percent file that allows readers to block until the buffer
    is filled to a given percent. This keeps the reader from causing events that
    will add noise to the trace.
  * tracefs_instance_clear()
    Helper to clear the contents of the current trace instance.
  * tep_get_sub_buffer_data_size()
    Helper to retrieve the current sub-buffer data size. The Linux kernel tracing
    ring buffer is broken up into smaller sub-buffers. This returns the size of
    the data portion of those sub-buffers (does not include the sub-buffer meta
    data).
  * tracefs_load_headers()
    API to just load the information about the sub-buffers and nothing more.
  * API to extract tracing ring buffer statistics
    tracefs_instance_get_stat()
    tracefs_instance_put_stat()
    tracefs_buffer_stat_entries()
    tracefs_buffer_stat_overrun()
    tracefs_buffer_stat_commit_overrun()
    tracefs_buffer_stat_bytes()
    tracefs_buffer_stat_event_timestamp()
    tracefs_buffer_stat_timestamp()
    tracefs_buffer_stat_dropped_events
  * tracefs_instance_set_subbuf_size() and tracefs_instance_get_subbuf_size()
    API to modify the sub-buffers size of the tracing ring buffer.
  * Added TIMESTAMP_DELTA and TIMESTAMP_DELTA_USECS to tracefs_sql() as a shortcut
    for (end.TIMESTAMP - start.TIMESTAMP) and (end.TIMESTAMP_USECS - start.TIMESTAMP_USECS)
    respectively
  * Add PID filtering API:
    tracefs_filter_pid_function()
  tracefs_filter_pid_events()
    tracefs_filter_pid_function_clear()
    tracefs_filter_pid_events_clear()
  * Added tracefs_cpu_snapshot_open() to read the raw data of snapshot buffers
  * Added snapshot functions:
    tracefs_snapshot_snap()
    tracefs_snapshot_clear()
    tracefs_snapshot_free()
  * Added ring buffer memory mapping APIs
    tracefs_cpu_open_mapped()
    tracefs_cpu_is_mapped()
    tracefs_mapped_is_supported()
    tracefs_cpu_map()
    tracefs_cpu_unmap()
  * Updates:
  - Increase pipe max size to max value when using splice.
  - Clear "max_graph_depth" on tracefs_instance_reset()
  - Add missing headers to syscall() and SYS_* defines
  - Add dependency fixes to meson build
  - Fix some documentation / man page issues
  - Fix memory leaks
  - Fix cscope rule
  - Fix issues in unit tests
  - Added many more unit tests
* Thu Jun 15 2023 Tony Jones <tonyj@suse.com>
- Add explicit thread dependency for older versions of meson (i.e SLE-15-SP5)
  New patch: add-explicit-meson-thread-dependency.patch
* Thu Jun 15 2023 Tony Jones <tonyj@suse.com>
- Update to version 1.7.0
  * Add initial support for meson
  * Add tracefs_kprobe_destroy() to index man page
  * State that tracefs_dynevent_create() is needed for tracefs_kprobe_alloc()
  * Add missing prototypes in top level man page
  * Add tracefs_kprobe_destory() API
  * Add helper function to destroy dynamic event
  * Add tracefs_time_conversion() API
  * Add tracefs_find_cid_pid() API
  * Fix crashing of synth test when synths exist
  * Do not use synth for test_synth element
  * Clarify the tracefs_synth_create() man page
  * Do not allow tracefs_synth_set_instance() on created synth
  * Documentation for tracefs_synth_set_instance
  * New API to set synthetic event instance
  * Do not segfault in tests if synthetic events are not configured
  * Add tracefs_instance_tracers() API
  * Do not use hwlat tracer and fdb_delete event for test
  * Add stacktrace to tracefs_sql()
  * Unit test for tracefs_instance_reset()
  * Documentation for tracefs_instance_reset()
  * New API to reset ftrace instance
- Drop patch 0001-libtracefs-Add-initial-support-for-meson.patch (upstream)
* Tue Feb  7 2023 Daniel Wagner <daniel.wagner@suse.com>
- Sync meson build patch with latest upstream version
  * Documentation is built via extra build target
* Wed Jan 18 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.4:
  * Flush pipe data in tracefs_cpu_flush()
  * Add check for duplicate functions in man pages
  * Make sure 32 bit works on 64 bit file systems
* Tue Dec 27 2022 Daniel Wagner <daniel.wagner@suse.com>
- Use meson to build package
  * add 0001-libtracefs-Add-initial-support-for-meson.patch
* Fri Dec 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.3
  * Fix a regression of where tracefs_tracing_dir() did not mount
    the tracefs file system if it was not already mounted.
    Same for mounting debugfs with tracefs_debug_dir().
  * Have tracefs_tracing_dir() and tracefs_debug_dir() check if the
    cached directory still exists and is mounted.
* Fri Nov 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.1
  * Fix tracefs_iterate_raw_events() to handle NULL callback
* Wed Nov 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.0
  * No changelog provided by upstream
  * A set of new API functions
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.2
  * Build fixes only (parallel build, musl support)
* Tue Jun 21 2022 Jan Engelhardt <jengelh@inai.de>
- Force make -j1 during build because of object file corruption.
* Tue Jun  7 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (1.4.1)
  * Raw uprobe API: tracefs_uprobe_alloc(), tracefs_uretprobe_alloc
  * Return the debugfs mount point from tracefs_debug_dir()
  * sqlhst: Fix labels being ignored for synthetic event field
  * sqlhst: Allow same event to be both the start and end event
  * sqlhst: Use unique names for labels
  * sqlhst: Report errors when executing commands
* Tue Apr  5 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (1.3.1)
  * Optimized string list handling. It was always stated that some string
    lists must be freed with tracefs_list_free(), and now it is mandatory, as
    metadata is used to store the size, and normal freeing of the list will
    cause memory issues.
  * More consistency with errno values
  * sqlhist is now officially built
  * New methods for setting and reading affinity
    tracefs_instance_set_affinity_set()
    tracefs_instance_set_affinity_raw()
    tracefs_instance_set_affinity()
    tracefs_instance_get_affinity()
    tracefs_instance_get_affinity_raw()
    tracefs_instance_get_affinity_set()
  * New method to see the system tracers
    tracefs_instances()
  * New methods to read and clear the error log
    tracefs_error_last()
    tracefs_error_all()
    tracefs_error_clear()
  * New methods to modify the string lists
    tracefs_list_add()
    tracefs_list_size()
  * New method to stop the iterator over raw events
    tracefs_iterate_stop()
  * New methods to make it easier to access event files
    tracefs_event_get_file()
    tracefs_event_file_read()
    tracefs_event_file_write()
    tracefs_event_file_append()
    tracefs_event_file_clear()
    tracefs_event_file_exists()
  * New method to get the available filter functions
    tracefs_filter_functions()
  * New methods to enable or disable tracers
    tracefs_tracer_set()
    tracefs_tracer_clear()
  * New methods for streaming the trace_pipe file
    tracefs_trace_pipe_stream()
    tracefs_trace_pipe_print()
    tracefs_trace_pipe_stop()
  * New methods for creating, modifying and destroying dynamic events
    tracefs_dynevent_create()
    tracefs_dynevent_destroy()
    tracefs_dynevent_destroy_all()
    tracefs_dynevent_free()
    tracefs_dynevent_list_free()
    tracefs_dynevent_get_all()
    tracefs_dynevent_get()
    tracefs_dynevent_info()
    tracefs_dynevent_get_event()
  * New method to create an event probe (then use dynamic methods above)
    tracefs_eprobe_alloc()
  * New methods to create kprobes and kretprobes
    tracefs_kprobe_alloc()
    tracefs_kretprobe_alloc()
    tracefs_kprobe_raw()
    tracefs_kretprobe_raw()
  * New methods for creating, modifying and destroying histograms
    tracefs_hist_free()
    tracefs_hist_alloc()
    tracefs_hist_alloc_2d()
    tracefs_hist_alloc_nd()
    tracefs_hist_get_name()
    tracefs_hist_get_event()
    tracefs_hist_get_system()
    tracefs_hist_add_key()
    tracefs_hist_add_value()
    tracefs_hist_add_sort_key()
    tracefs_hist_set_sort_key()
    tracefs_hist_sort_key_direction()
    tracefs_hist_add_name()
    tracefs_hist_append_filter()
    tracefs_hist_echo_cmd()
    tracefs_hist_command()
    tracefs_hist_start()
    tracefs_hist_pause()
    tracefs_hist_continue()
    tracefs_hist_reset()
    tracefs_hist_destroy()
  * New methods for creating, modifying and destroying synthetic events
    tracefs_synth_get_name()
    tracefs_synth *tracefs_synth_alloc()
    tracefs_synth_add_match_field()
    tracefs_synth_add_compare_field()
    tracefs_synth_add_start_field()
    tracefs_synth_add_end_field()
    tracefs_synth_append_start_filter()
    tracefs_synth_append_end_filter()
    tracefs_synth_trace()
    tracefs_synth_snapshot()
    tracefs_synth_save()
    tracefs_synth_complete()
    tracefs_synth_get_start_hist()
    tracefs_synth_create()
    tracefs_synth_destroy()
    tracefs_synth_free()
    tracefs_synth_echo_cmd()
    tracefs_synth_raw_fmt()
    tracefs_synth_show_event()
    tracefs_synth_show_start_hist()
    tracefs_synth_show_end_hist()
    tracefs_synth_get_event()
  * New methods to modify event filters
    tracefs_filter_string_append()
    tracefs_filter_string_verify()
    tracefs_event_filter_apply()
    tracefs_event_filter_clear()
    tracefs_event_append_filter()
    tracefs_event_verify_filter()
  * New method to create a synthetic event via a SQL string
    tracefs_sql()
    The man page comes with its own program (sqlhist).
* Tue Feb 22 2022 olaf@aepfle.de
- Force correct pkgconfig_dir location to fix build
* Wed Jan 19 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest upstream version (1.2.5)
  * No changelog provided again
* Fri May 14 2021 Dario Faggioli <dfaggioli@suse.com>
- Update to new upstream version (1.2.0)
  * No changelog was provided by upstream.
  * libtracefs: Add tracefs_event_enable/disable() API
* Mon May 10 2021 Dario Faggioli <dfaggioli@suse.com>
- update to new upstream version (1.1.2)
- drop patch 294319.patch (already present upstream)
* Tue Dec 22 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 1.0.0) for build.opensuse.org
- Add 294319.patch
